<!-- NoiseLevelManage 噪音分类管理 -->
<template>
    <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <div class="search-container">
            <el-form ref="form" :model="parameter" label-width="auto">
                <el-row :gutter="10">
                    <el-col :span="6">
                        <el-form-item label="噪音分类">
                            <!-- <el-input v-model="querys[0].value" clearable placeholder="请输入噪音分类"></el-input> -->
                            <el-select style="width: 100%" v-model="querys[0].value" clearable placeholder="请选择噪音分类">
                                <el-option v-for="item in sortList" :key="item.id" :label="item.name" :value="item.id">
                                </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>

                    <el-col :span="6">
                        <el-form-item label="分类级别">
                            <el-select style="width: 100%" v-model="querys[1].value" clearable placeholder="请选择分类级别">
                                <el-option v-for="item in fljbList" :key="item.value" :label="item.name"
                                    :value="item.value">
                                </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="6">
                        <el-form-item label="状态">
                            <el-select style="width: 100%" v-model="querys[2].value" clearable placeholder="请选择分类级别">
                                <el-option label="启用" value="1"></el-option>
                                <el-option label="禁用" value="0"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="getData(1)">
                            {{ this.$t('common.search') }}
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" :class="['main-table-container', 'flex']">
            <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
                <div style="margin-bottom: 10px" ref="btnPanel">
                    <el-button icon="el-icon-plus" type="primary" class="btn btn-plus" @click="handleAdd" v-methodauth="'NoiseLevelManage_add'">
                        添加
                    </el-button>
                    <el-button slot="reference" icon="el-icon-delete" type="danger" class="btn btn-delete" v-methodauth="'NoiseLevelManage_delete'"
                        @click="handleDelete('deletes')" :disabled="deleteIds ? false : true">
                       删除
                    </el-button>
                </div>
                <div class="table-wrapper">
                    <el-table stripe size="mini" v-loading="tableLoading" ref="tableData" :data="tableData" height="100%"
                        :style="{ width: '100%' }" @selection-change="handleSelectionChange"
                        :default-sort="{ prop: 'status', order: 'ascending' }">
                        <el-table-column type="selection" width="55" align="center"
                            :selectable="selectable"></el-table-column>
                        <el-table-column type="index" label="序号" align="center">
                        </el-table-column>
                        <el-table-column prop="noiseTypeName" show-overflow-tooltip  label="噪音分类"
                            align="center">
                        </el-table-column>
                        <el-table-column prop="code" show-overflow-tooltip  label="分级编码" align="center">
                        </el-table-column>
                        <el-table-column prop="levelName" show-overflow-tooltip  label="分类级别" align="center">
                        </el-table-column>
                        <el-table-column prop="daytimeNoiseLevel" show-overflow-tooltip  label="白天噪音分贝标准"
                            align="center">
                        </el-table-column>
                        <el-table-column prop="nightNoiseLevel" show-overflow-tooltip  label="晚上噪音分贝标准"
                            align="center">
                        </el-table-column>
                        <el-table-column prop="status" show-overflow-tooltip  label="启用禁用" align="center">
                            <template v-slot="{ row }">
                                <el-switch v-model="row.status" @change="enableOrProhibit(row)" active-value="0" inactive-value="1" v-methodauth="'NoiseLevelManage_status'">
                              </el-switch>
                            </template>
                        </el-table-column>
                        <el-table-column show-overflow-tooltip align="center" min-width="180" label="操作">
                            <template v-slot="{ row }">
                                <!-- <el-link type="primary" v-if="row.status === '0'" :underline="false" class="cloumn-btn"
                                    @click="enableOrProhibit(row)">
                                    启用
                                </el-link>
                                <el-link v-if="row.status === '1'" type="danger" :underline="false" class="cloumn-btn"
                                    @click="enableOrProhibit(row)">
                                    禁用
                                </el-link> -->
                                <el-link type="primary" :underline="false" style="margin: 0 10px" class="cloumn-btn" v-methodauth="'NoiseLevelManage_edit'"
                                    @click="handleEdit(row)">
                                    编辑
                                </el-link>
                                <el-link type="danger" :underline="false" class="cloumn-btn" v-methodauth="'NoiseLevelManage_delete'"
                                    @click="handleDelete('delete', row)">
                                    删除
                                </el-link>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="pageResult"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
                <NoiseLevelDialog ref="formDialog" @getData="getData" />
            </el-col>
        </el-row>
    </div>
</template>
<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import NoiseLevel from '@/api/basicConfiguration/NoiseLevel'
import NoiseLevelDialog from './components/NoiseLevelDialog'
import utils from '@/utils.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import NoiseClassify from '@/api/basicConfiguration/NoiseClassify'

export default {
    name: 'NoiseLevelManage',
    components: {
        pagination,
        NoiseLevelDialog,
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            tableMaxHeight: 400,
            tableData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            querys: [
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'noise_type_id_',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'level',
                    relation: 'AND',
                    value: '',
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'l.status_',
                    relation: 'AND',
                    value: '',
                },
            ],
            reqData: {
                querys: [],
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
            },
            tableLoading: false,
            deleteIds: '',
            parameter: {
                size: 20,
                page: 1,
            },
            sortList: []
        }
    },

    created() {
        this.fljbList = dictUtils.getDictItemsFromCache('fljb')

        this.getData()
        this.getSortData()
    },
    methods: {
        // 获取噪音分类
        getSortData() {
            NoiseClassify.dataQuery({
                pageBean: {
                    page: 1,
                    pageSize: -1,
                }
            }, (res) => {
                this.sortList = res.rows
            })
        },
        selectable(row) {
            if (row.isDele === '1') {
                return false
            } else {
                return true
            }
        },
        //获取数据
        getData(page) {
            if (page) {
                this.reqData.pageBean.page = page
            }
            this.reqData.querys = []
            if (this.querys[0].value) {
                this.reqData.querys.push(this.querys[0])
            }
            if (this.querys[1].value) {
                this.reqData.querys.push(this.querys[1])
            }
            if (this.querys[2].value) {
                this.reqData.querys.push(this.querys[2])
            }

            this.tableLoading = true
            NoiseLevel.dataQuery(this.reqData, (res) => {
                this.pageResult.total = res.total
                this.tableLoading = false
                this.tableData = res.rows
                this.tableData.forEach(e => {
                    this.fljbList.forEach(f => {
                        if (e.level == f.value) {
                            e.levelName = f.name
                        }
                    })
                })
            })
        },

        // 编辑
        handleEdit(item) {
            this.$refs.formDialog.edit(item.id)
        },
        //启用or禁止
        enableOrProhibit(val) {
            NoiseLevel.enableDisable({ id: val.id }, (res) => {
                if (res.state) {
                    this.$message.success(
                        val.status === '0'
                            ? '启用成功'
                            : val.status === '1'
                                ? '禁用成功'
                                : ''
                    )
                    this.getData()
                }
            })
        },
        //获取删除数据id集合
        handleSelectionChange(val) {
            let arr = val.map((item) => item.id)
            this.deleteIds = arr.join(',')
            console.log(this.deleteIds)
        },
        //删除
        handleDelete(type, val) {
            console.log(val)
            this.$confirm('确认删除吗？', this.$t('common.tips'), {
                confirmButtonText: this.$t('common.confirm'),
                cancelButtonText: this.$t('common.cancel'),
                type: 'warning',
            }).then(() => {
                this.markLoading = true
                if (type === 'delete') {
                    NoiseLevel.remove(val.id, (res) => {
                        if (res.state) {
                            this.getData()
                            this.$message.success('删除成功')
                            this.markLoading = false
                        } else {
                            this.markLoading = false
                        }
                    })
                } else {
                    NoiseLevel.batchRemove(this.deleteIds, (res) => {
                        if (res.state) {
                            this.getData()
                            this.$message.success('删除成功')
                            this.markLoading = false
                        } else {
                            this.markLoading = false
                        }
                    })
                }
            })
        },
        handleSizeChange(val) {
            this.reqData.pageBean.pageSize = val
            this.getData()
        },
        handleCurrentChange(val) {
            this.reqData.pageBean.page = val
            this.getData()
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
    },
}
</script>
  
<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';
@import '~@/assets/css/common.scss';
</style>